@@ -1,6 +1,6 @@
 /*  
     Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
-    Copyright (C) 1999  Ales Cepek <cepek@gnu.org>
+    Copyright (C) 1999, 2006  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU GaMa / GaMaLib C++ Library.
     
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: adj_gso.h,v 1.1 2006/04/09 16:40:25 cepek Exp $
+ *  $Id: adj_gso.h,v 1.5 2006/08/26 13:23:30 cepek Exp $
  */
 
 #ifndef GNU_Gama_gnu_gama_gnugama_GaMa_OLS_gso_h
@@ -33,33 +33,23 @@
 namespace GNU_gama {
   
 template <typename Float, typename Exc>
-class AdjGSO : public virtual AdjBase<Float, Exc> {
+class AdjGSO : public AdjBaseFull<Float, Exc> {
 
 public:
 
   AdjGSO() {}
   AdjGSO(const Mat<Float, Exc>& A, const Vec<Float, Exc>& b)
-    : AdjBase<Float, Exc>(A, b) {}
+    : AdjBaseFull<Float, Exc>(A, b) {}
   
   void reset(const Mat<Float, Exc>& A, 
              const Vec<Float, Exc>& b)
     {
-      AdjBase<Float, Exc>::reset(A, b);
-    }
-  
-  const Vec<Float, Exc>& solve(Vec<Float, Exc>& x)
-    {
-      return x = AdjBase<Float, Exc>::solve();
-    }
-  const Vec<Float, Exc>& solve() 
-    { 
-      return AdjBase<Float, Exc>::solve(); 
+      AdjBaseFull<Float, Exc>::reset(A, b);
     }
   
   Index defect() { return gso.defect(); }
   bool  lindep(Index i) { return gso.lindep(i); }
   
-  void  q_xx(Mat<Float, Exc>& C) { AdjBase<Float, Exc>::q_xx(C); }
   Float q_xx(Index i, Index j);
   Float q_bb(Index i, Index j);
   Float q_bx(Index i, Index j);
@@ -67,10 +57,7 @@ public:
   void min_x() { gso.min_x(); }
   void min_x(Index n, Index x[]) { gso.min_x(n, x); }
   
-  
-protected:
-  
-  void solve_me();
+  void solve();
    
 private:
 
@@ -84,7 +71,7 @@ private:
 
 
 template <typename Float, typename Exc>
-void AdjGSO<Float, Exc>::solve_me()
+void AdjGSO<Float, Exc>::solve()
 {
   if (this->is_solved) return;
 
@@ -125,7 +112,7 @@ void AdjGSO<Float, Exc>::solve_me()
 template <typename Float, typename Exc>
 Float AdjGSO<Float, Exc>::q_xx(Index i, Index j)
   {
-    if(!this->is_solved) solve_me();
+    if(!this->is_solved) solve();
     const Index M = this->pA->rows();
     const Index N = this->pA->cols();
     i += M;
@@ -140,7 +127,7 @@ Float AdjGSO<Float, Exc>::q_xx(Index i, Index j)
 template <typename Float, typename Exc>
 Float AdjGSO<Float, Exc>::q_bb(Index i, Index j)
   {
-    if(!this->is_solved) solve_me();
+    if(!this->is_solved) solve();
 
     const Index N = this->pA->cols();
     Float s = 0;                        
@@ -153,7 +140,7 @@ Float AdjGSO<Float, Exc>::q_bb(Index i, Index j)
 template <typename Float, typename Exc>
 Float AdjGSO<Float, Exc>::q_bx(Index i, Index j)
   {
-    if(!this->is_solved) solve_me();
+    if(!this->is_solved) solve();
 
     const Index M = this->pA->rows();
     const Index N = this->pA->cols();
