@@ -1,6 +1,6 @@
 /*  
     Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
-    Copyright (C) 1999  Ales Cepek <cepek@gnu.org>
+    Copyright (C) 1999, 2006  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU GaMa / GaMaLib C++ Library.
     
@@ -20,57 +20,50 @@
 */
 
 /*
- *  $Id: adj_svd.h,v 1.1 2006/04/09 16:40:25 cepek Exp $
+ *  $Id: adj_svd.h,v 1.6 2006/08/26 13:23:30 cepek Exp $
  */
 
 #ifndef GNU_Gama__gnu_gama__gnu_gama_GaMa_OLS_svd_h
 #define GNU_Gama__gnu_gama__gnu_gama_GaMa_OLS_svd_h
 
 #include <gnu_gama/adj/adj_base.h>
+#include <matvec/svd.h>
 #include <cmath>
 
 namespace GNU_gama {
   
 template <typename Float, typename Exc>
-class AdjSVD : virtual public AdjBase<Float, Exc> {
+class AdjSVD : public AdjBaseFull<Float, Exc> {
 
   SVD<Float, Exc> svd;
 
 public:
   AdjSVD() {}
   AdjSVD(const Mat<Float, Exc>& A, const Vec<Float, Exc>& b)
-    : AdjBase<Float, Exc>(A, b) {}
+    : AdjBaseFull<Float, Exc>(A, b) {}
   
-  void reset(const Mat<Float, Exc>& A, 
-             const Vec<Float, Exc>& b)
+  void reset(const Mat<Float, Exc>& A, const Vec<Float, Exc>& b)
     {
-      AdjBase<Float, Exc>::reset(A, b);
+      AdjBaseFull<Float, Exc>::reset(A, b);
       svd.reset(A);
     }
   
-  const Vec<Float, Exc>& solve(Vec<Float, Exc>& x)
-    {
-      return x = AdjBase<Float, Exc>::solve();
-    }
-  const Vec<Float, Exc>& solve() { return AdjBase<Float, Exc>::solve(); }
-  
   Index defect() { return svd.nullity(); }
   bool  lindep(Index i) { return svd.lindep(i); }
   
-  void  q_xx(Mat<Float, Exc>& C) { AdjBase<Float, Exc>::q_xx(C); }
   Float q_xx(Index i, Index j)
     {
-      if(!this->is_solved) solve_me();
+      if(!this->is_solved) solve();
       return svd.q_xx(i, j);
     }
   Float q_bb(Index i, Index j)
     {
-      if (!this->is_solved) solve_me();
+      if (!this->is_solved) solve();
       return svd.q_bb(i, j);
     }
   Float q_bx(Index i, Index j)
     {
-      if (!this->is_solved) solve_me();
+      if (!this->is_solved) solve();
       return svd.q_bx(i, j);
     }
   
@@ -78,17 +71,14 @@ public:
   void min_x(Index n, Index x[]) { svd.min_x(n, x); }
 
   Float cond();
-  
-protected:
-  
-   void solve_me();
+  void solve();
    
 };
 
 // ...................................................................
 
 template <typename Float, typename Exc>
-void AdjSVD<Float, Exc>::solve_me()
+void AdjSVD<Float, Exc>::solve()
 {
    using namespace GNU_gama; 
    using namespace std;
